@@ -22,12 +22,26 @@ def getProducts():
     print("Error listing products: ", e) 
    finally:
     connection.close()        
-def getProduct(id): 
-    dprodut=DTProduct(0,"")
-    for p in getProducts():
-     if(id==p.id):
-      dprodut=p;
-    return dprodut
+def getProduct(idprod):   
+   try:
+        # Get the sql connection
+     queryproduct='Select * from Producto where IdProducto=?'
+     connection = getConnection()
+     cursor = connection.cursor()
+
+        # Execute the sql query
+     cursorp =cursor.execute(queryproduct,[idprod])
+     result=cursor.fetchall();
+     row=result[0]
+     id=int(row[0])
+     image=str(row[1])
+     perobjet=DTProduct(id,image)
+     return perobjet
+     
+   except Exception as e:
+    print("Error searching products: ", e) 
+   finally:
+    connection.close() 
 def insertProduct(product):
   try:
            connection = getConnection()
@@ -94,10 +108,16 @@ for x in list:
   print(x.image)
   print("------------")
 
-obj=getProduct(5)
+obj=getProduct(10)
 print(obj.id)
 print(obj.image)
-"""
+""" 
+def getProduct(id): 
+    dprodut=DTProduct(0,"")
+    for p in getProducts():
+     if(id==p.id):
+      dprodut=p;
+    return dprodut
 prouct=DTProduct(17,"gds.jpg")
  mensaje=insertProduct(prouct)
  mensaje=updateProduct(prouct)
